@@ -3,7 +3,7 @@
 =begin
     mo.rb - A simple class for operating GNU MO file.
 
-    Copyright (C) 2012  Kouhei Sutou <kou@clear-code.com>
+    Copyright (C) 2012-2022  Sutou Kouhei <kou@clear-code.com>
     Copyright (C) 2003-2009  Masao Mutoh
     Copyright (C) 2002  Masahiro Sakai, Masao Mutoh
     Copyright (C) 2001  Masahiro Sakai
@@ -19,6 +19,8 @@
 
 require 'stringio'
 
+require 'prime'
+
 module GetText
   class MO < Hash
     class InvalidFormat < RuntimeError; end;
@@ -43,8 +45,8 @@ module GetText
       :trans_sysdep_tab_offset
     end
 
-    MAGIC_BIG_ENDIAN    = "\x95\x04\x12\xde".force_encoding("ASCII-8BIT")
-    MAGIC_LITTLE_ENDIAN = "\xde\x12\x04\x95".force_encoding("ASCII-8BIT")
+    MAGIC_BIG_ENDIAN    = "\x95\x04\x12\xde".b
+    MAGIC_LITTLE_ENDIAN = "\xde\x12\x04\x95".b
 
     def self.open(arg = nil, output_charset = nil)
       result = self.new(output_charset)
@@ -168,19 +170,8 @@ module GetText
       ('1' * number) !~ /^1?$|^(11+?)\1+$/
     end
 
-    begin
-      require 'prime'
-      def next_prime(seed)
-        Prime.instance.find{|x| x > seed }
-      end
-    rescue LoadError
-      def next_prime(seed)
-        require 'mathn'
-        prime = Prime.new
-        while current = prime.succ
-          return current if current > seed
-        end
-      end
+    def next_prime(seed)
+      Prime.instance.find{|x| x > seed }
     end
 
     HASHWORDBITS = 32
@@ -278,11 +269,13 @@ module GetText
 
     def load_from_file(filename)
       @filename = filename
-      begin
-        File.open(filename, 'rb'){|f| load_from_stream(f)}
-      rescue => e
-        e.set_backtrace("File: #{@filename}")
-        raise e
+      File.open(filename, 'rb') do |f|
+        begin
+          load_from_stream(f)
+        rescue => e
+          e.set_backtrace(["#{filename}:#{f.lineno}"] + e.backtrace)
+          raise e
+        end
       end
     end
 
@@ -318,21 +311,14 @@ module GetText
         return string
       end
 
-      begin
-        string.encode(@output_charset, @charset)
-      rescue EncodingError
-        if $DEBUG
-          warn "@charset = ", @charset
-          warn "@output_charset = ", @output_charset
-          warn "msgid = ", original_string
-          warn "msgstr = ", string
-        end
-        string
-      end
+      string.encode(@output_charset,
+                    @charset,
+                    :invalid => :replace,
+                    :undef => :replace)
     end
 
     def generate_original_string(msgid, options)
-      string = ""
+      string = String.new
 
       msgctxt = options.delete(:msgctxt)
       msgid_plural = options.delete(:msgid_plural)
