@@ -222,6 +222,21 @@ class TestRubyParser < Test::Unit::TestCase
                    path)
     end
 
+    def test_pipe
+      path = "pipe.rb"
+      assert_parse([
+                     {
+                       :msgid      => "Hello",
+                       :references => ["#{path}:26"],
+                     },
+                     {
+                       :msgid      => "World",
+                       :references => ["#{path}:28"],
+                     },
+                   ],
+                   path)
+    end
+
     private
     def fixture_path(*components)
       super("_", *components)
@@ -266,4 +281,31 @@ class TestRubyParser < Test::Unit::TestCase
       super("ns_", *components)
     end
   end
+
+  sub_test_case("parse") do
+    def test_percent_w
+      assert_parse([],
+                   "percent_lower_w.rb")
+    end
+
+    def test_percent_W
+      assert_parse([],
+                   "percent_upper_w.rb")
+    end
+
+    def test_percent_i
+      assert_parse([],
+                   "percent_lower_i.rb")
+    end
+
+    def test_percent_I
+      assert_parse([],
+                   "percent_upper_i.rb")
+    end
+
+    private
+    def fixture_path(*components)
+      super("ruby", *components)
+    end
+  end
 end
